@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Prereqs::CheckCircular;
 
-our $DATE = '2018-01-14'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2021-05-31'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,7 +65,8 @@ sub after_build {
 
     return unless @$mods;
 
-    $res = call_lcpan_script(argv=>["deps", "-R", @$mods]);
+    $res = call_lcpan_script(argv=>["deps", "-R",
+                                    map {("--module",$_)} @$mods]);
     $self->log_fatal(["Can't lcpan deps: %s - %s", $res->[0], $res->[1]])
         unless $res->[0] == 200;
     for my $entry (@{$res->[2]}) {
@@ -96,7 +97,7 @@ Dist::Zilla::Plugin::Prereqs::CheckCircular - Check for circular/recursive depen
 
 =head1 VERSION
 
-This document describes version 0.006 of Dist::Zilla::Plugin::Prereqs::CheckCircular (from Perl distribution Dist-Zilla-Plugin-Prereqs-CheckCircular), released on 2018-01-14.
+This document describes version 0.007 of Dist::Zilla::Plugin::Prereqs::CheckCircular (from Perl distribution Dist-Zilla-Plugin-Prereqs-CheckCircular), released on 2021-05-31.
 
 =head1 SYNOPSIS
 
@@ -146,7 +147,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
